Enum libpulse_binding::callbacks::ListResult [−][src]
pub enum ListResult<T> {
Item(T),
End,
Error,
}Expand description
List result instance.
Fetching a list can result in a callback being fired for each list item, and then once more to signal the end of the list having been reached. This type is used to distinguish such state to a closure callback.
Variants
List item
End of list reached
Failure, an error occurred