[][src]Enum libpulse_binding::channelmap::MapDef

#[repr(C)]
pub enum MapDef { AIFF, ALSA, Aux, WAVEEx, OSS, }

Variants

AIFF

The mapping from RFC3551, which is based on AIFF-C.

ALSA

The default mapping used by ALSA. This mapping is probably not too useful since ALSA’s default channel mapping depends on the device string used.

Aux

Only aux channels.

WAVEEx

Microsoft’s WAVEFORMATEXTENSIBLE mapping. This mapping works as if all LSBs of dwChannelMask are set.

OSS

The default channel mapping used by OSS as defined in the OSS 4.0 API specs. This mapping is probably not too useful since the OSS API has changed in this respect and no longer knows a default channel mapping based on the number of channels.