Enum libpulse_binding::channelmap::Position [−][src]
#[repr(C)]
pub enum Position {
Show 52 variants
Invalid,
Mono,
FrontLeft,
FrontRight,
FrontCenter,
RearCenter,
RearLeft,
RearRight,
Lfe,
FrontLeftOfCenter,
FrontRightOfCenter,
SideLeft,
SideRight,
Aux0,
Aux1,
Aux2,
Aux3,
Aux4,
Aux5,
Aux6,
Aux7,
Aux8,
Aux9,
Aux10,
Aux11,
Aux12,
Aux13,
Aux14,
Aux15,
Aux16,
Aux17,
Aux18,
Aux19,
Aux20,
Aux21,
Aux22,
Aux23,
Aux24,
Aux25,
Aux26,
Aux27,
Aux28,
Aux29,
Aux30,
Aux31,
TopCenter,
TopFrontLeft,
TopFrontRight,
TopFrontCenter,
TopRearLeft,
TopRearRight,
TopRearCenter,
}Expand description
A list of channel labels.
Note, certain aliases, specifically Left, Right, Center and Subwoofer, available in the
equivalent C enum are not provided here, since Rust does not allow aliases.
Variants
Invalid.
Mono.
Apple, Dolby call this ‘Left’.
Apple, Dolby call this ‘Right’.
Apple, Dolby call this ‘Center’.
Microsoft calls this ‘Back Center’, Apple calls this ‘Center Surround’, Dolby calls this ‘Surround Rear Center’.
Microsoft calls this ‘Back Left’, Apple calls this ‘Left Surround’, Dolby calls this ‘Surround Rear Left’.
Microsoft calls this ‘Back Right’, Apple calls this ‘Right Surround’, Dolby calls this ‘Surround Rear Right’.
Aka subwoofer. Microsoft calls this ‘Low Frequency’, Apple calls this ‘LFEScreen’.
Apple, Dolby call this ‘Left Center’.
Apple, Dolby call this ‘Right Center’.
Apple calls this ‘Left Surround Direct’, Dolby calls this ‘Surround Left’.
Apple calls this ‘Right Surround Direct’, Dolby calls this ‘Surround Right’.
Auxillary 0.
Auxillary 1.
Auxillary 2.
Auxillary 3.
Auxillary 4.
Auxillary 5.
Auxillary 6.
Auxillary 7.
Auxillary 8.
Auxillary 9.
Auxillary 10.
Auxillary 11.
Auxillary 12.
Auxillary 13.
Auxillary 14.
Auxillary 15.
Auxillary 16.
Auxillary 17.
Auxillary 18.
Auxillary 19.
Auxillary 20.
Auxillary 21.
Auxillary 22.
Auxillary 23.
Auxillary 24.
Auxillary 25.
Auxillary 26.
Auxillary 27.
Auxillary 28.
Auxillary 29.
Auxillary 30.
Auxillary 31.
Apple calls this ‘Top Center Surround’.
Apple calls this ‘Vertical Height Left’.
Apple calls this ‘Vertical Height Right’.
Apple calls this ‘Vertical Height Center’.
Microsoft and Apple call this ‘Top Back Left’.
Microsoft and Apple call this ‘Top Back Right’.
Microsoft and Apple call this ‘Top Back Center’.
Implementations
Makes a bit mask from a channel position.
Gets a text label for the specified channel position.
Gets a human readable text label for the specified channel position.
Creates a new instance from a string representation, as given by
to_string().