[−][src]Enum libpulse_binding::context::State
The state of a connection context
Variants
UnconnectedThe context hasn’t been connected yet.
ConnectingA connection is being established.
AuthorizingThe client is authorizing itself to the daemon.
SettingNameThe client is passing its application name to the daemon.
ReadyThe connection is established, the context is ready to execute operations.
FailedThe connection failed or was disconnected.
TerminatedThe connection was terminated cleanly.
Methods
impl State[src]