logo
Routines for controlling module-device-manager.

Structs

A wrapper object providing device manager routines to a context.

Stores information about one device in the device database that is maintained by module-device-manager.

Role priority information.