Module libpulse_binding::context::ext_stream_restore
source ·
[−]Expand description
Routines for controlling module-stream-restore.
Structs
Stores information about one entry in the stream database that is maintained by module-stream-restore.
A wrapper object providing stream restore routines to a context.