Struct libpulse_binding::context::ext_stream_restore::StreamRestore
[−]
[src]
pub struct StreamRestore { /* fields omitted */ }A wrapper object providing stream restore routines to a context.
Methods
impl StreamRestore[src]
pub fn from_raw_weak(context: *mut ContextInternal) -> Self[src]
Create a new DeviceManager from an existing
ContextInternal pointer. This is the 'weak' version, for
use in callbacks, which avoids destroying the internal object when dropped.
pub fn test(&mut self, cb: (TestCb, *mut c_void)) -> Option<Operation>[src]
Test if this extension module is available in the server.
pub fn read(&mut self, cb: (ReadCb, *mut c_void)) -> Option<Operation>[src]
Read all entries from the stream database.
pub fn write(
&mut self,
mode: UpdateMode,
data: &[&Info],
apply_immediately: bool,
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>[src]
&mut self,
mode: UpdateMode,
data: &[&Info],
apply_immediately: bool,
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>
Store entries in the stream database.
pub fn delete(
&mut self,
streams: &[&str],
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>[src]
&mut self,
streams: &[&str],
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>
Delete entries from the stream database.
pub fn subscribe(
&mut self,
enable: bool,
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>[src]
&mut self,
enable: bool,
cb: (ContextSuccessCb, *mut c_void)
) -> Option<Operation>
Subscribe to changes in the stream database.
pub fn set_subscribe_cb(&mut self, cb: (SubscribeCb, *mut c_void))[src]
Set the subscription callback that is called when subscribe was
called.