Struct libpulse_binding::context::introspect::CardProfileInfo2
source ·
[−]pub struct CardProfileInfo2<'a> {
pub name: Option<Cow<'a, str>>,
pub description: Option<Cow<'a, str>>,
pub n_sinks: u32,
pub n_sources: u32,
pub priority: u32,
pub available: bool,
}This is supported on crate feature
pa_v5 only.Expand description
Stores information about a specific profile of a card.
Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.
Fields
name: Option<Cow<'a, str>>Name of this profile.
description: Option<Cow<'a, str>>Description of this profile.
n_sinks: u32Number of sinks this profile would create.
n_sources: u32Number of sources this profile would create.
priority: u32The higher this value is, the more useful this profile is as a default.
available: boolIs this profile available? If this is false, meaning “unavailable”, then it makes no sense
to try to activate this profile. If this is true, it’s still not a guarantee that
activating the profile will result in anything useful, it just means that the server isn’t
aware of any reason why the profile would definitely be useless.