[][src]Struct libpulse_binding::context::introspect::ClientInfo

pub struct ClientInfo<'a> {
    pub index: u32,
    pub name: Option<Cow<'a, str>>,
    pub owner_module: Option<u32>,
    pub driver: Option<Cow<'a, str>>,
    pub proplist: Proplist,
}

Stores information about clients.

Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.

Fields

index: u32

Index of this client.

name: Option<Cow<'a, str>>

Name of this client.

owner_module: Option<u32>

Index of the owning module, or None.

driver: Option<Cow<'a, str>>

Driver name.

proplist: Proplist

Property list.