Struct libpulse_binding::context::introspect::ServerInfo
source ·
[−]pub struct ServerInfo<'a> {
pub user_name: Option<Cow<'a, str>>,
pub host_name: Option<Cow<'a, str>>,
pub server_version: Option<Cow<'a, str>>,
pub server_name: Option<Cow<'a, str>>,
pub sample_spec: Spec,
pub default_sink_name: Option<Cow<'a, str>>,
pub default_source_name: Option<Cow<'a, str>>,
pub cookie: u32,
pub channel_map: Map,
}Expand description
Server information.
Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.
Fields
user_name: Option<Cow<'a, str>>User name of the daemon process.
host_name: Option<Cow<'a, str>>Host name the daemon is running on.
server_version: Option<Cow<'a, str>>Version string of the daemon.
server_name: Option<Cow<'a, str>>Server package name (usually “pulseaudio”).
sample_spec: SpecDefault sample specification.
default_sink_name: Option<Cow<'a, str>>Name of default sink.
default_source_name: Option<Cow<'a, str>>Name of default source.
A random cookie for identifying this instance of PulseAudio.
channel_map: MapDefault channel map.