[][src]Struct libpulse_binding::context::introspect::SinkPortInfo

#[repr(C)]
pub struct SinkPortInfo<'a> { pub name: Option<Cow<'a, str>>, pub description: Option<Cow<'a, str>>, pub priority: u32, pub available: PortAvailable, }

Stores information about a specific port of a sink.

Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.

Fields

name: Option<Cow<'a, str>>

Name of this port.

description: Option<Cow<'a, str>>

Description of this port.

priority: u32

The higher this value is, the more useful this port is as a default.

available: PortAvailable

A flag indicating availability status of this port.