[][src]Struct libpulse_binding::context::introspect::StatInfo

#[repr(C)]
pub struct StatInfo { pub memblock_total: u32, pub memblock_total_size: u32, pub memblock_allocated: u32, pub memblock_allocated_size: u32, pub scache_size: u32, }

Memory block statistics.

Please note that this structure can be extended as part of evolutionary API updates at any time in any new release.

Fields

memblock_total: u32

Currently allocated memory blocks.

memblock_total_size: u32

Current total size of allocated memory blocks.

memblock_allocated: u32

Allocated memory blocks during the whole lifetime of the daemon.

memblock_allocated_size: u32

Total size of all memory blocks allocated during the whole lifetime of the daemon.

scache_size: u32

Total size of all sample cache entries.