Module libpulse_binding::context::subscribe::subscription_masks
source · Expand description
A set of masks used for expressing which facilities you are interested in when subscribing.
A set of masks used for expressing which facilities you are interested in when subscribing.