Type Definition libpulse_binding::context::subscribe::EventType[][src]

pub type EventType = u32;
The base integer type passed to the callback, from which the facility and operation components can be extracted.