Enum libpulse_binding::def::SinkState
source ·
[−]#[repr(C)]
pub enum SinkState {
Invalid,
Running,
Idle,
Suspended,
}Expand description
Sink state.
Variants
Invalid
This state is used when the server does not support sink state introspection.
Running
Running, sink is playing and used by at least one non-corked sink-input.
Idle
When idle, the sink is playing but there is no non-corked sink-input attached to it.
Suspended
When suspended, actual sink access can be closed, for instance.
Implementations