[][src]Enum libpulse_binding::def::SourceState

#[repr(C)]
pub enum SourceState { Invalid, Running, Idle, Suspended, }

Source state.

Variants

Invalid

This state is used when the server does not support source state introspection.

Running

Running, source is recording and used by at least one non-corked source-output.

Idle

When idle, the source is still recording but there is no non-corked source-output.

Suspended

When suspended, actual source access can be closed, for instance.

Methods

impl SourceState[src]

pub fn is_opened(self) -> bool[src]

Returns true if source is recording: running or idle.

pub fn is_running(self) -> bool[src]

Returns true if source is running.