Module libpulse_binding::def::source_flags
source ·
[−]Use the associated constants on SourceFlagSet.
Special source flags.
Constants
Volume can be translated to dB with the From based conversions between Volume,
VolumeLinear and VolumeDB types. This is a dynamic flag and may change at runtime
after the source has initialized.
The latency can be adjusted dynamically depending on the needs of the connected streams.
This source is in flat volume mode, i.e. always the maximum of the volume of all connected outputs.
Is a hardware source of some kind, in contrast to “virtual”/software source.
Supports hardware mute control. This is a dynamic flag and may change at runtime after the source has initialized.
Supports hardware volume control. This is a dynamic flag and may change at runtime after the source has initialized.
Supports latency querying.
Is a networked source of some kind.
Flag to pass when no specific options are needed.