[−][src]Struct libpulse_binding::mainloop::api::MainloopApi
An abstract mainloop API vtable
Fields
userdata: *mut c_voidA pointer to some private, arbitrary data of the main loop implementation
io_new: Option<extern "C" fn(a: *const MainloopApi, fd: i32, events: IoEventFlagSet, cb: Option<IoEventCb>, userdata: *mut c_void) -> *mut IoEventInternal>Create a new IO event source object
io_enable: Option<extern "C" fn(e: *mut IoEventInternal, events: IoEventFlagSet)>Enable or disable IO events on this object
io_free: Option<extern "C" fn(e: *mut IoEventInternal)>Free a IO event source object
io_set_destroy: Option<extern "C" fn(e: *mut IoEventInternal, cb: Option<IoEventDestroyCb>)>Set a function that is called when the IO event source is destroyed. Use this to free the
userdata argument if required.
time_new: Option<extern "C" fn(a: *const MainloopApi, tv: *const timeval, cb: Option<TimeEventCb>, userdata: *mut c_void) -> *mut TimeEventInternal>Create a new timer event source object for the specified Unix time
time_restart: Option<extern "C" fn(e: *mut TimeEventInternal, tv: *const timeval)>Restart a running or expired timer event source with a new Unix time
time_free: Option<extern "C" fn(e: *mut TimeEventInternal)>Free a deferred timer event source object
time_set_destroy: Option<extern "C" fn(e: *mut TimeEventInternal, cb: Option<TimeEventDestroyCb>)>Set a function that is called when the timer event source is destroyed. Use this to free the
userdata argument if required.
defer_new: Option<extern "C" fn(a: *const MainloopApi, cb: Option<DeferEventCb>, userdata: *mut c_void) -> *mut DeferEventInternal>Create a new deferred event source object
defer_enable: Option<extern "C" fn(e: *mut DeferEventInternal, b: i32)>Enable or disable a deferred event source temporarily
defer_free: Option<extern "C" fn(e: *mut DeferEventInternal)>Free a deferred event source object
defer_set_destroy: Option<extern "C" fn(e: *mut DeferEventInternal, cb: Option<DeferEventDestroyCb>)>Set a function that is called when the deferred event source is
destroyed. Use this to free the userdata argument if required.
quit: Option<extern "C" fn(a: *const MainloopApi, retval: RetvalActual)>Exit the main loop and return the specified retval