pub trait MainloopInternalType { }Expand description
This enables generic type enforcement with the opaque C objects.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait MainloopInternalType { }This enables generic type enforcement with the opaque C objects.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".