Main loop deferred events.

Structs

A deferred event source
An opaque deferred event source object.
A reference to a deferred event source, provided to the callback, allowing modification within the callback itself