Struct libpulse_binding::mainloop::events::deferred::DeferEventRef [−][src]
pub struct DeferEventRef<T: 'static> where
T: MainloopInnerType, { /* fields omitted */ }Expand description
A reference to a deferred event source, provided to the callback, allowing modification within the callback itself.