Struct libpulse_binding::mainloop::events::timer::TimeEventRef [−][src]
pub struct TimeEventRef<T: 'static> where
T: MainloopInnerType, { /* fields omitted */ }Expand description
A reference to a timer event source, provided to the callback, allowing modification within the callback itself.
Implementations
Restarts this timer event source (whether still running or already expired) with a new Unix time.
Restarts this timer event source (whether still running or already expired) with a new monotonic time.