pub struct Event { /* fields omitted */ }
An opaque UNIX signal event source object.
Note: Saves a copy of the closure callbacks, which it frees on drop.
Creates a new UNIX signal event source object.
The callback must accept an integer which represents the signal.
Executes the destructor for this type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.