Enum libpulse_binding::mainloop::standard::IterateResult[][src]

pub enum IterateResult {
    Success(u32),
    Quit(Retval),
    Err(PAErr),
}
Return type for Mainloop::iterate().

Variants

Success

Success, with number of sources dispatched.

Tuple Fields of Success

0: u32
Quit

Quit was called, with quit’s retval.

Tuple Fields of Quit

0: Retval
Err

An error occurred, with error value.

Tuple Fields of Err

0: PAErr

Implementations

Checks if the result is a Success value (returns true if so).

Checks if the result is a Quit value (returns true if so).

Checksif the result is anErrorvalue (returnstrue` if so).