Enum libpulse_binding::sample::Format
[−]
[src]
#[repr(C)]pub enum Format { U8, ALaw, ULaw, S16le, S16be, F32le, F32be, S32le, S32be, S24le, S24be, S24_32le, S24_32be, Invalid, }
Sample format
Variants
U8Unsigned 8 Bit PCM.
ALaw8 Bit a-Law.
ULaw8 Bit mu-Law.
S16leSigned 16 Bit PCM, little endian (PC).
S16beSigned 16 Bit PCM, big endian.
F32le32 Bit IEEE floating point, little endian (PC), range -1.0 to 1.0.
F32be32 Bit IEEE floating point, big endian, range -1.0 to 1.0.
S32leSigned 32 Bit PCM, little endian (PC).
S32beSigned 32 Bit PCM, big endian.
S24leSigned 24 Bit PCM packed, little endian (PC).
S24beSigned 24 Bit PCM packed, big endian.
S24_32leSigned 24 Bit PCM in LSB of 32 Bit words, little endian (PC).
S24_32beSigned 24 Bit PCM in LSB of 32 Bit words, big endian.
InvalidAn invalid value.
Methods
impl Format[src]
pub fn size(&self) -> usize[src]
Similar to Spec::sample_size but take a sample
format instead of full sample spec.
pub fn to_string(&self) -> Option<String>[src]
Returns a descriptive string for the specified sample format.
pub fn parse(format: &str) -> Self[src]
Parse a sample format text. Inverse of to_string.
pub fn is_le(&self) -> Option<bool>[src]
Returns true when the specified format is little endian, false if big endian. Returns
None when endianness does not apply to this format, or if unknown.
pub fn is_be(&self) -> Option<bool>[src]
Returns true when the specified format is big endian, false if little endian. Returns
None when endianness does not apply to this format, or if unknown.
pub fn is_ne(&self) -> Option<bool>[src]
Is format native endian?
Returns true when the specified format is native endian, false when not. Returns None
when endianness does not apply to the specified format, or endianess is unknown
pub fn is_re(&self) -> Option<bool>[src]
Is format reverse of native endian?
Returns true when the specified format is reverse endian, false when not. Returns None
when endianness does not apply to the specified format, or endianess is unknown.