Enum libpulse_binding::stream::PeekResult[][src]

pub enum PeekResult<'a> {
    Empty,
    Hole(usize),
    Data(&'a [u8]),
}
Result type for the Stream::peek() method. See documentation of the method itself for more information.

Variants

Empty

No data (Null data pointer and size of 0 returned by PA).

Hole

Data hole with given size (Null pointer with non-zero size returned by PA).

Tuple Fields of Hole

0: usize
Data

Data available, with slice into memory returned by PA.

Tuple Fields of Data

0: &'a [u8]