[][src]Enum libpulse_binding::stream::SeekMode

#[repr(C)]
pub enum SeekMode { Relative, Absolute, RelativeOnRead, RelativeEnd, }

Variants

Relative

Seek relatively to the write index.

Absolute

Seek relatively to the start of the buffer queue.

RelativeOnRead

Seek relatively to the read index.

RelativeEnd

Seek relatively to the current end of the buffer queue.