[][src]Enum libpulse_binding::stream::State

#[repr(C)]
pub enum State { Unconnected, Creating, Ready, Failed, Terminated, }

The state of a stream

Variants

Unconnected

The stream is not yet connected to any sink or source.

Creating

The stream is being created.

Ready

The stream is established, you may pass audio data to it now.

Failed

An error occurred that made the stream invalid.

Terminated

The stream has been terminated cleanly.

Methods

impl State[src]

pub fn is_good(self) -> bool[src]

Returns true if the passed state is one of the connected states.