Module libpulse_binding::stream::event_names
source · Expand description
Common event names supplied to the set_event_callback callback.
Constants
A stream event notifying that the stream is going to be disconnected because the underlying
sink changed and no longer supports the format that was originally negotiated. Clients need
to connect a new stream to renegotiate a format and continue playback.
A stream policy/meta event requesting that an application should cork a specific stream.
A stream policy/meta event requesting that an application should cork a specific stream.