Struct libpulse_binding::time::MonotonicTs
source ·
[−]pub struct MonotonicTs(_);Expand description
A monotonic timestamp.
Implementations
Gets the current monotonic system time in microseconds.
Note, if such a clock is not available then this will actually fall back to the wallclock
time instead. No indication is available for whether or not this is the case, and the
return value is still a MonotonicTs type.
Returns true so long as inner value is not MicroSeconds::INVALID.
Checked integer addition. Computes self + rhs, returning None if overflow occurred,
using the inner MicroSeconds’s checked_add() method.
Checked integer addition. Computes self + rhs, returning None if overflow occurred,
using the inner integer’s checked_add() method.
Checked integer subtraction. Computes self - rhs, returning None if overflow occurred,
using the inner MicroSeconds’s checked_sub() method.
Checked integer subtraction. Computes self - rhs, returning None if overflow occurred,
using the inner integer’s checked_sub() method.