Struct libpulse_binding::timeval::Timeval
[−]
[src]
#[repr(C)]pub struct Timeval(pub timeval);
Wrapper for libc::timeval, providing trait impls
Warning, this must remain directly transmutable with the inner libc::timeval
Methods
impl Timeval[src]
ⓘImportant traits for &'a mut Wpub fn get_time_of_day(&mut self) -> &mut Self[src]
Obtain the current wallclock timestamp, just like UNIX gettimeofday().
pub fn diff(a: &Self, b: &Self) -> MicroSeconds[src]
Calculate the difference between the two specified timeval structs.
pub fn age(&self) -> MicroSeconds[src]
Return the time difference between now and self
pub fn add(&mut self, t: MicroSeconds)[src]
Add the specified time in microseconds
pub fn sub(&mut self, t: MicroSeconds)[src]
Subtract the specified time in microseconds
pub fn set(&mut self, t: MicroSeconds)[src]
Set the specified usec value