Struct libpulse_binding::volume::Volume
[−]
[src]
pub struct Volume(pub pa_volume_t);
Software volume expressed as an integer
Methods
impl Volume[src]
pub fn is_muted(&self) -> bool[src]
pub fn is_normal(&self) -> bool[src]
pub fn is_max(&self) -> bool[src]
pub fn ui_max() -> Self[src]
Recommended maximum volume to show in user facing UIs. Note: UIs should deal gracefully with volumes greater than this value and not cause feedback loops etc. - i.e. if the volume is more than this, the UI should not limit it and push the limited value back to the server.
pub fn is_valid(&self) -> bool[src]
Check if volume is valid.
pub fn clamp(&mut self)[src]
Clamp volume to the permitted range.
pub fn multiply(a: Self, b: Self) -> Self[src]
Multiply two software volumes, return the result.
This uses VOLUME_NORM as neutral element of multiplication.
This is only valid for software volumes!
pub fn divide(a: Self, b: Self) -> Self[src]
Divide two software volumes, return the result.
This uses VOLUME_NORM as neutral element of division. This is
only valid for software volumes! If a division by zero is tried the result will be 0.
pub fn print(&self) -> String[src]
Pretty print a volume
pub fn print_db(&self) -> String[src]
Pretty print a volume but show dB values.
pub fn print_verbose(&self, print_db: bool) -> String[src]
Pretty print a volume in a verbose way.
The volume is printed in several formats: the raw volume value, percentage, and if
print_db is true, also the dB value.