[−][src]Enum libpulse_binding::channelmap::MapDef
Variants
AIFFThe mapping from RFC3551, which is based on AIFF-C.
ALSAThe default mapping used by ALSA. This mapping is probably not too useful since ALSA’s default channel mapping depends on the device string used.
AuxOnly aux channels.
WAVEExMicrosoft’s WAVEFORMATEXTENSIBLE mapping. This mapping works as if all LSBs of dwChannelMask are set.
OSSThe default channel mapping used by OSS as defined in the OSS 4.0 API specs. This mapping is probably not too useful since the OSS API has changed in this respect and no longer knows a default channel mapping based on the number of channels.