[][src]Enum libpulse_binding::channelmap::Position

#[repr(C)]
pub enum Position { Invalid, Mono, FrontLeft, FrontRight, FrontCenter, RearCenter, RearLeft, RearRight, Lfe, FrontLeftOfCenter, FrontRightOfCenter, SideLeft, SideRight, Aux0, Aux1, Aux2, Aux3, Aux4, Aux5, Aux6, Aux7, Aux8, Aux9, Aux10, Aux11, Aux12, Aux13, Aux14, Aux15, Aux16, Aux17, Aux18, Aux19, Aux20, Aux21, Aux22, Aux23, Aux24, Aux25, Aux26, Aux27, Aux28, Aux29, Aux30, Aux31, TopCenter, TopFrontLeft, TopFrontRight, TopFrontCenter, TopRearLeft, TopRearRight, TopRearCenter, }

A list of channel labels

Note, certain aliases, specifically Left, Right, Center and Subwoofer, available in the equivalent C enum are not provided here, since Rust does not allow aliases.

Variants

InvalidMonoFrontLeft

Apple, Dolby call this ‘Left’

FrontRight

Apple, Dolby call this ‘Right’

FrontCenter

Apple, Dolby call this ‘Center’

RearCenter

Microsoft calls this ‘Back Center’, Apple calls this ‘Center Surround’, Dolby calls this ‘Surround Rear Center’

RearLeft

Microsoft calls this ‘Back Left’, Apple calls this ‘Left Surround’, Dolby calls this ‘Surround Rear Left’

RearRight

Microsoft calls this ‘Back Right’, Apple calls this ‘Right Surround’, Dolby calls this ‘Surround Rear Right’

Lfe

Aka subwoofer. Microsoft calls this ‘Low Frequency’, Apple calls this ‘LFEScreen’

FrontLeftOfCenter

Apple, Dolby call this ‘Left Center’

FrontRightOfCenter

Apple, Dolby call this ‘Right Center’

SideLeft

Apple calls this ‘Left Surround Direct’, Dolby calls this ‘Surround Left’

SideRight

Apple calls this ‘Right Surround Direct’, Dolby calls this ‘Surround Right’

Aux0Aux1Aux2Aux3Aux4Aux5Aux6Aux7Aux8Aux9Aux10Aux11Aux12Aux13Aux14Aux15Aux16Aux17Aux18Aux19Aux20Aux21Aux22Aux23Aux24Aux25Aux26Aux27Aux28Aux29Aux30Aux31TopCenter

Apple calls this ‘Top Center Surround’

TopFrontLeft

Apple calls this ‘Vertical Height Left’

TopFrontRight

Apple calls this ‘Vertical Height Right’

TopFrontCenter

Apple calls this ‘Vertical Height Center’

TopRearLeft

Microsoft and Apple call this ‘Top Back Left’

TopRearRight

Microsoft and Apple call this ‘Top Back Right’

TopRearCenter

Microsoft and Apple call this ‘Top Back Center’

Methods

impl Position[src]

pub fn to_mask(self) -> PositionMask[src]

Makes a bit mask from a channel position.

pub fn to_string(pos: Self) -> Option<Cow<'static, str>>[src]

Return a text label for the specified channel position

pub fn to_pretty_string(pos: Self) -> Option<String>[src]

Return a human readable text label for the specified channel position.

pub fn from_string(s: &str) -> Self[src]

The inverse of to_string.