[−][src]Enum libpulse_binding::channelmap::Position
A list of channel labels
Note, certain aliases, specifically Left, Right, Center and Subwoofer, available in the
equivalent C enum are not provided here, since Rust does not allow aliases.
Variants
InvalidMonoFrontLeftApple, Dolby call this ‘Left’
FrontRightApple, Dolby call this ‘Right’
FrontCenterApple, Dolby call this ‘Center’
RearCenterMicrosoft calls this ‘Back Center’, Apple calls this ‘Center Surround’, Dolby calls this ‘Surround Rear Center’
RearLeftMicrosoft calls this ‘Back Left’, Apple calls this ‘Left Surround’, Dolby calls this ‘Surround Rear Left’
RearRightMicrosoft calls this ‘Back Right’, Apple calls this ‘Right Surround’, Dolby calls this ‘Surround Rear Right’
LfeAka subwoofer. Microsoft calls this ‘Low Frequency’, Apple calls this ‘LFEScreen’
FrontLeftOfCenterApple, Dolby call this ‘Left Center’
FrontRightOfCenterApple, Dolby call this ‘Right Center’
SideLeftApple calls this ‘Left Surround Direct’, Dolby calls this ‘Surround Left’
SideRightApple calls this ‘Right Surround Direct’, Dolby calls this ‘Surround Right’
Aux0Aux1Aux2Aux3Aux4Aux5Aux6Aux7Aux8Aux9Aux10Aux11Aux12Aux13Aux14Aux15Aux16Aux17Aux18Aux19Aux20Aux21Aux22Aux23Aux24Aux25Aux26Aux27Aux28Aux29Aux30Aux31TopCenterApple calls this ‘Top Center Surround’
TopFrontLeftApple calls this ‘Vertical Height Left’
TopFrontRightApple calls this ‘Vertical Height Right’
TopFrontCenterApple calls this ‘Vertical Height Center’
TopRearLeftMicrosoft and Apple call this ‘Top Back Left’
TopRearRightMicrosoft and Apple call this ‘Top Back Right’
TopRearCenterMicrosoft and Apple call this ‘Top Back Center’
Methods
impl Position[src]
pub fn to_mask(self) -> PositionMask[src]
Makes a bit mask from a channel position.
pub fn to_string(pos: Self) -> Option<Cow<'static, str>>[src]
Return a text label for the specified channel position
pub fn to_pretty_string(pos: Self) -> Option<String>[src]
Return a human readable text label for the specified channel position.
pub fn from_string(s: &str) -> Self[src]
The inverse of to_string.