[−][src]Module libpulse_binding::context::ext_device_manager
Routines for controlling module-device-manager.
Structs
| DeviceManager | A wrapper object providing device manager routines to a context. Note: Saves a copy of active multi-use closure callbacks, which it frees on drop. |
| Info | Stores information about one device in the device database that is maintained by module-device-manager. |
| RolePriorityInfo |