Module libpulse_binding::context::ext_device_restore[][src]

Routines for controlling module-device-restore.

Structs

A wrapper object providing device restore routines to a context.

Stores information about one device in the device database that is maintained by module-device-manager.