[−][src]Module libpulse_binding::context::ext_stream_restore
Routines for controlling module-stream-restore.
Structs
| Info | Stores information about one entry in the stream database that is maintained by module-stream-restore. |
| StreamRestore | A wrapper object providing stream restore routines to a context. Note: Saves a copy of active multi-use closure callbacks, which it frees on drop. |