[][src]Enum libpulse_binding::def::PortAvailable

#[repr(C)]
pub enum PortAvailable { Unknown, No, Yes, }

Variants

Unknown

This port does not support jack detection

No

This port is not available, likely because the jack is not plugged in.

Yes

This port is available, likely because the jack is plugged in.