[−][src]Enum libpulse_binding::def::PortAvailable
Variants
UnknownThis port does not support jack detection
NoThis port is not available, likely because the jack is not plugged in.
YesThis port is available, likely because the jack is plugged in.