Enum libpulse_binding::mainloop::standard::InterateResult
[−]
[src]
pub enum InterateResult {
Success(u32),
Quit(Retval),
Err(PAErr),
}Return type for Mainloop::iterate.
Variants
Success(u32)Success, with number of sources dispatched
Quit(Retval)Quit was called, with quit's retval
Err(PAErr)An error occurred, with error value
Methods
impl InterateResult[src]
pub fn is_success(&self) -> bool[src]
Returns true if the result is a Success value.
pub fn is_quit(&self) -> bool[src]
Returns true if the result is a Quit value.
pub fn is_error(&self) -> bool[src]
Returns true if the result is an Error value.