Struct libpulse_binding::sample::Spec
[−]
[src]
#[repr(C)]pub struct Spec { pub format: Format, pub rate: u32, pub channels: u8, }
A sample format and attribute specification
Fields
format: Format
The sample format.
rate: u32
The sample rate. (e.g. 44100).
channels: u8
Audio channels. (1 for mono, 2 for stereo, ...).
Methods
impl Spec[src]
pub fn init(&mut self)[src]
Initialize the specified sample spec.
The sample spec will have a defined state but is_valid will fail for
it.
pub fn is_valid(&self) -> bool[src]
Returns true when the sample type specification is valid
pub fn equal_to(&self, to: &Self) -> bool[src]
Returns true when the two sample type specifications match
pub fn bytes_per_second(&self) -> usize[src]
Returns the amount of bytes that constitute playback of one second of audio, with the specified sample type.
pub fn frame_size(&self) -> usize[src]
Returns the size of a frame
pub fn sample_size(&self) -> usize[src]
Returns the size of a sample
pub fn bytes_to_usec(&self, length: u64) -> MicroSeconds[src]
Calculate the time it would take to play a buffer of the specified size. The return value will always be rounded down for non-integral return values.
pub fn usec_to_bytes(&self, t: MicroSeconds) -> usize[src]
Calculates the size of a buffer required, for playback duration of the time specified. The return value will always be rounded down for non-integral return values.
pub fn print(&self) -> String[src]
Pretty print a sample type specification to a string