[][src]Enum libpulse_binding::stream::PeekResult

pub enum PeekResult<'a> {
    Empty,
    Hole(usize),
    Data(&'a [u8]),
}

Result type for the Stream::Peek method. See documentation of the method itself for more information.

Variants

Empty

No data (Null data pointer and size of 0 returned by PA).

Hole(usize)

Data hole with given size (Null pointer with non-zero size returned by PA).

Data(&'a [u8])

Data available, with slice into memory returned by PA.