[−][src]Enum libpulse_binding::stream::SeekMode
Variants
RelativeSeek relatively to the write index.
AbsoluteSeek relatively to the start of the buffer queue.
RelativeOnReadSeek relatively to the read index.
RelativeEndSeek relatively to the current end of the buffer queue.