[−][src]Enum libpulse_binding::stream::State
The state of a stream
Variants
UnconnectedThe stream is not yet connected to any sink or source.
CreatingThe stream is being created.
ReadyThe stream is established, you may pass audio data to it now.
FailedAn error occurred that made the stream invalid.
TerminatedThe stream has been terminated cleanly.
Methods
impl State[src]