[−][src]Struct libpulse_binding::time::MonotonicTs
A monotonic timestamp
Methods
impl MonotonicTs[src]
pub fn now() -> Self[src]
Return the current monotonic system time in microseconds.
Note, if such a clock is not available then this will actually fall back to the wallclock
time instead. No indication is available for whether or not this is the case, and the
return value is still a MonotonicTs type.
pub fn is_valid(&self) -> bool[src]
pub fn checked_add(self, other: MicroSeconds) -> Option<Self>[src]
pub fn checked_sub(self, other: MicroSeconds) -> Option<Self>[src]